# Assesment_Creator Python Package.

Steps: Install the Python package via pip
```
pip install assesment-creator
```
1. Import the package and call assesment_creator API method.

```python
from assesment_creator import create_assesment
create_assesment(url_link,filename)
```
# Documentation:
[Documentation](https://sachinmishra-ux.github.io/assesment_creator/)